@@ -17,6 +17,7 @@ from vnpy.trader.object import BarData, TickData
 from vnpy.trader.database import (
     BaseDatabase,
     BarOverview,
+    TickOverview,
     DB_TZ,
     convert_tz
 )
@@ -31,8 +32,11 @@ from vnpy.trader.utility import (
 class InfluxdbDatabase(BaseDatabase):
     """InfluxDB数据库接口"""
 
-    overview_filename = "influxdb_overview"
-    overview_filepath = str(get_file_path(overview_filename))
+    bar_overview_filename = "influxdb_baroverview"
+    bar_overview_filepath = str(get_file_path(bar_overview_filename))
+
+    tick_overview_filename = "influxdb_tickoverview"
+    tick_overview_filepath = str(get_file_path(tick_overview_filename))
 
     def __init__(self) -> None:
         """"""
@@ -55,7 +59,7 @@ class InfluxdbDatabase(BaseDatabase):
         self.query_api: QueryApi = self.client.query_api()
         self.delete_api: DeleteApi = self.client.delete_api()
 
-    def save_bar_data(self, bars: List[BarData]) -> bool:
+    def save_bar_data(self, bars: List[BarData], stream: bool = False) -> bool:
         """保存K线数据"""
         data: List[dict] = []
 
@@ -76,13 +80,13 @@ class InfluxdbDatabase(BaseDatabase):
                 },
                 "time": bar.datetime.isoformat(),
                 "fields": {
-                    "open_price": bar.open_price,
-                    "high_price": bar.high_price,
-                    "low_price": bar.low_price,
-                    "close_price": bar.close_price,
-                    "volume": bar.volume,
-                    "turnover": bar.turnover,
-                    "open_interest": bar.open_interest,
+                    "open_price": float(bar.open_price),
+                    "high_price": float(bar.high_price),
+                    "low_price": float(bar.low_price),
+                    "close_price": float(bar.close_price),
+                    "volume": float(bar.volume),
+                    "turnover": float(bar.turnover),
+                    "open_interest": float(bar.open_interest),
                 }
             }
             data.append(d)
@@ -97,7 +101,7 @@ class InfluxdbDatabase(BaseDatabase):
         symbol, exchange = extract_vt_symbol(vt_symbol)
         key = f"{vt_symbol}_{interval.value}"
 
-        f = shelve.open(self.overview_filepath)
+        f = shelve.open(self.bar_overview_filepath)
         overview = f.get(key, None)
 
         if not overview:
@@ -109,6 +113,9 @@ class InfluxdbDatabase(BaseDatabase):
             overview.count = len(bars)
             overview.start = bars[0].datetime
             overview.end = bars[-1].datetime
+        elif stream:
+            overview.end = bars[-1].datetime
+            overview.count += len(bars)
         else:
             overview.start = min(overview.start, bars[0].datetime)
             overview.end = max(overview.end, bars[-1].datetime)
@@ -135,7 +142,7 @@ class InfluxdbDatabase(BaseDatabase):
 
         return True
 
-    def save_tick_data(self, ticks: List[TickData]) -> bool:
+    def save_tick_data(self, ticks: List[TickData], stream: bool = False) -> bool:
         """保存TICK数据"""
         data: List[dict] = []
 
@@ -157,42 +164,42 @@ class InfluxdbDatabase(BaseDatabase):
                 "time": tick.datetime.isoformat(),
                 "fields": {
                     "name": tick.name,
-                    "volume": tick.volume,
-                    "turnover": tick.turnover,
-                    "open_interest": tick.open_interest,
-                    "last_price": tick.last_price,
-                    "last_volume": tick.last_volume,
-                    "limit_up": tick.limit_up,
-                    "limit_down": tick.limit_down,
+                    "volume": float(tick.volume),
+                    "turnover": float(tick.turnover),
+                    "open_interest": float(tick.open_interest),
+                    "last_price": float(tick.last_price),
+                    "last_volume": float(tick.last_volume),
+                    "limit_up": float(tick.limit_up),
+                    "limit_down": float(tick.limit_down),
 
-                    "open_price": tick.open_price,
-                    "high_price": tick.high_price,
-                    "low_price": tick.low_price,
-                    "pre_close": tick.pre_close,
+                    "open_price": float(tick.open_price),
+                    "high_price": float(tick.high_price),
+                    "low_price": float(tick.low_price),
+                    "pre_close": float(tick.pre_close),
 
-                    "bid_price_1": tick.bid_price_1,
-                    "bid_price_2": tick.bid_price_2,
-                    "bid_price_3": tick.bid_price_3,
-                    "bid_price_4": tick.bid_price_4,
-                    "bid_price_5": tick.bid_price_5,
+                    "bid_price_1": float(tick.bid_price_1),
+                    "bid_price_2": float(tick.bid_price_2),
+                    "bid_price_3": float(tick.bid_price_3),
+                    "bid_price_4": float(tick.bid_price_4),
+                    "bid_price_5": float(tick.bid_price_5),
 
-                    "ask_price_1": tick.ask_price_1,
-                    "ask_price_2": tick.ask_price_2,
-                    "ask_price_3": tick.ask_price_3,
-                    "ask_price_4": tick.ask_price_4,
-                    "ask_price_5": tick.ask_price_5,
+                    "ask_price_1": float(tick.ask_price_1),
+                    "ask_price_2": float(tick.ask_price_2),
+                    "ask_price_3": float(tick.ask_price_3),
+                    "ask_price_4": float(tick.ask_price_4),
+                    "ask_price_5": float(tick.ask_price_5),
 
-                    "bid_volume_1": tick.bid_volume_1,
-                    "bid_volume_2": tick.bid_volume_2,
-                    "bid_volume_3": tick.bid_volume_3,
-                    "bid_volume_4": tick.bid_volume_4,
-                    "bid_volume_5": tick.bid_volume_5,
+                    "bid_volume_1": float(tick.bid_volume_1),
+                    "bid_volume_2": float(tick.bid_volume_2),
+                    "bid_volume_3": float(tick.bid_volume_3),
+                    "bid_volume_4": float(tick.bid_volume_4),
+                    "bid_volume_5": float(tick.bid_volume_5),
 
-                    "ask_volume_1": tick.ask_volume_1,
-                    "ask_volume_2": tick.ask_volume_2,
-                    "ask_volume_3": tick.ask_volume_3,
-                    "ask_volume_4": tick.ask_volume_4,
-                    "ask_volume_5": tick.ask_volume_5,
+                    "ask_volume_1": float(tick.ask_volume_1),
+                    "ask_volume_2": float(tick.ask_volume_2),
+                    "ask_volume_3": float(tick.ask_volume_3),
+                    "ask_volume_4": float(tick.ask_volume_4),
+                    "ask_volume_5": float(tick.ask_volume_5),
 
                     "localtime": tick.localtime.timestamp()
                 }
@@ -205,6 +212,47 @@ class InfluxdbDatabase(BaseDatabase):
             record=data
         )
 
+        # 更新Tick汇总数据
+        symbol, exchange = extract_vt_symbol(vt_symbol)
+        key = f"{vt_symbol}"
+
+        f = shelve.open(self.tick_overview_filepath)
+        overview = f.get(key, None)
+
+        if not overview:
+            overview = TickOverview(
+                symbol=symbol,
+                exchange=exchange
+            )
+            overview.count = len(ticks)
+            overview.start = ticks[0].datetime
+            overview.end = ticks[-1].datetime
+        elif stream:
+            overview.end = ticks[-1].datetime
+            overview.count += len(ticks)
+        else:
+            overview.start = min(overview.start, ticks[0].datetime)
+            overview.end = max(overview.end, ticks[-1].datetime)
+
+            query: str = f'''
+                from(bucket: "{self.database}")
+                    |> range(start: 2000-01-01T00:00:00Z, stop: {datetime.now().isoformat()}Z)
+                    |> filter(fn: (r) =>
+                        r._measurement == "tick_data" and
+                        r.vt_symbol == "{vt_symbol}" and
+                        r._field == "close_price"
+                    )
+                    |> count()
+                    |> yield(name: "count")
+            '''
+            df: DataFrame = self.query_api.query_data_frame(query)
+
+            for tp in df.itertuples():
+                overview.count = tp._5
+
+        f[key] = overview
+        f.close()
+
         return True
 
     def load_bar_data(
@@ -244,13 +292,13 @@ class InfluxdbDatabase(BaseDatabase):
                 exchange=exchange,
                 interval=interval,
                 datetime=dt,
-                open_price=tp[14],
-                high_price=tp[11],
-                low_price=tp[12],
-                close_price=tp[10],
-                volume=tp[16],
-                turnover=tp[15],
-                open_interest=tp[13],
+                open_price=float(tp[14]),
+                high_price=float(tp[11]),
+                low_price=float(tp[12]),
+                close_price=float(tp[10]),
+                volume=float(tp[16]),
+                turnover=float(tp[15]),
+                open_interest=float(tp[13]),
                 gateway_name="DB"
             )
             bars.append(bar)
@@ -292,37 +340,37 @@ class InfluxdbDatabase(BaseDatabase):
                 exchange=exchange,
                 datetime=dt,
                 name=tp[36],
-                volume=tp[41],
-                turnover=tp[40],
-                open_interest=tp[37],
-                last_price=tp[30],
-                last_volume=tp[31],
-                limit_up=tp[33],
-                limit_down=tp[32],
-                open_price=tp[38],
-                high_price=tp[29],
-                low_price=tp[35],
-                pre_close=tp[39],
-                bid_price_1=tp[19],
-                bid_price_2=tp[20],
-                bid_price_3=tp[21],
-                bid_price_4=tp[22],
-                bid_price_5=tp[23],
-                ask_price_1=tp[9],
-                ask_price_2=tp[10],
-                ask_price_3=tp[11],
-                ask_price_4=tp[12],
-                ask_price_5=tp[13],
-                bid_volume_1=tp[24],
-                bid_volume_2=tp[25],
-                bid_volume_3=tp[26],
-                bid_volume_4=tp[27],
-                bid_volume_5=tp[28],
-                ask_volume_1=tp[14],
-                ask_volume_2=tp[15],
-                ask_volume_3=tp[16],
-                ask_volume_4=tp[17],
-                ask_volume_5=tp[18],
+                volume=float(tp[41]),
+                turnover=float(tp[40]),
+                open_interest=float(tp[37]),
+                last_price=float(tp[30]),
+                last_volume=float(tp[31]),
+                limit_up=float(tp[33]),
+                limit_down=float(tp[32]),
+                open_price=float(tp[38]),
+                high_price=float(tp[29]),
+                low_price=float(tp[35]),
+                pre_close=float(tp[39]),
+                bid_price_1=float(tp[19]),
+                bid_price_2=float(tp[20]),
+                bid_price_3=float(tp[21]),
+                bid_price_4=float(tp[22]),
+                bid_price_5=float(tp[23]),
+                ask_price_1=float(tp[9]),
+                ask_price_2=float(tp[10]),
+                ask_price_3=float(tp[11]),
+                ask_price_4=float(tp[12]),
+                ask_price_5=float(tp[13]),
+                bid_volume_1=float(tp[24]),
+                bid_volume_2=float(tp[25]),
+                bid_volume_3=float(tp[26]),
+                bid_volume_4=float(tp[27]),
+                bid_volume_5=float(tp[28]),
+                ask_volume_1=float(tp[14]),
+                ask_volume_2=float(tp[15]),
+                ask_volume_3=float(tp[16]),
+                ask_volume_4=float(tp[17]),
+                ask_volume_5=float(tp[18]),
                 localtime=datetime.fromtimestamp(float(tp[34])),
                 gateway_name="DB"
             )
@@ -368,7 +416,7 @@ class InfluxdbDatabase(BaseDatabase):
         )
 
         # 删除K线汇总数据
-        f = shelve.open(self.overview_filepath)
+        f = shelve.open(self.bar_overview_filepath)
         vt_symbol = generate_vt_symbol(symbol, exchange)
         key = f"{vt_symbol}_{interval.value}"
         if key in f:
@@ -411,11 +459,26 @@ class InfluxdbDatabase(BaseDatabase):
             org=self.user
         )
 
+        # 删除K线汇总数据
+        f = shelve.open(self.tick_overview_filepath)
+        vt_symbol = generate_vt_symbol(symbol, exchange)
+        key = f"{vt_symbol}"
+        if key in f:
+            f.pop(key)
+        f.close()
+
         return count
 
     def get_bar_overview(self) -> List[BarOverview]:
         """查询数据库中的K线汇总信息"""
-        f = shelve.open(self.overview_filepath)
+        f = shelve.open(self.bar_overview_filepath)
+        overviews = list(f.values())
+        f.close()
+        return overviews
+
+    def get_tick_overview(self) -> List[TickOverview]:
+        """查询数据库中的Tick汇总信息"""
+        f = shelve.open(self.tick_overview_filepath)
         overviews = list(f.values())
         f.close()
         return overviews
